@@ -63,7 +63,6 @@ __FBSDID("$FreeBSD$");
 
 #include <sys/param.h>
 #include <sys/stat.h>
-#include <sys/sysctl.h>
 #include <sys/time.h>
 #include <sys/queue.h>
 #include <sys/resource.h>
@@ -368,6 +367,7 @@ MainParseArgs(int argc, char **argv)
 {
 	int c;
 	Boolean	found_dd = FALSE;
+	char found_dir[MAXPATHLEN + 1];	/* for searching for sys.mk */
 
 rearg:
 	optind = 1;	/* since we're called more than once */
@@ -394,6 +394,8 @@ rearg:
 		case 'C':
 			if (chdir(optarg) == -1)
 				err(1, "chdir %s", optarg);
+			if (getcwd(curdir, MAXPATHLEN) == NULL)
+				err(2, NULL);
 			break;
 		case 'D':
 			Var_SetGlobal(optarg, "1");
@@ -492,7 +494,15 @@ rearg:
 			MFLAGS_append("-k", NULL);
 			break;
 		case 'm':
-			Path_AddDir(&sysIncPath, optarg);
+			/* look for magic parent directory search string */
+			if (strncmp(".../", optarg, 4) == 0) {
+				if (!Dir_FindHereOrAbove(curdir, optarg + 4,
+				    found_dir, sizeof(found_dir)))
+					break;		/* nothing doing */
+				Path_AddDir(&sysIncPath, found_dir);
+			} else {
+				Path_AddDir(&sysIncPath, optarg);
+			}
 			MFLAGS_append("-m", optarg);
 			break;
 		case 'n':
@@ -675,11 +685,9 @@ check_make_level(void)
 	int	level = (value == NULL) ? 0 : atoi(value);
 
 	if (level < 0) {
-		errc(2, EAGAIN, "Invalid value for recursion level (%d).",
-		    level);
+		errx(2, "Invalid value for recursion level (%d).", level);
 	} else if (level > MKLVL_MAXVAL) {
-		errc(2, EAGAIN, "Max recursion level (%d) exceeded.",
-		    MKLVL_MAXVAL);
+		errx(2, "Max recursion level (%d) exceeded.", MKLVL_MAXVAL);
 	} else {
 		char new_value[32];
 		sprintf(new_value, "%d", level + 1);
@@ -706,6 +714,7 @@ Main_AddSourceMakefile(const char *name)
 static void
 Remake_Makefiles(void)
 {
+	Lst cleanup;
 	LstNode *ln;
 	int error_cnt = 0;
 	int remade_cnt = 0;
@@ -716,6 +725,7 @@ Remake_Makefiles(void)
 			Fatal("Failed to change directory to %s.", curdir);
 	}
 
+	Lst_Init(&cleanup);
 	LST_FOREACH(ln, &source_makefiles) {
 		LstNode *ln2;
 		struct GNode *gn;
@@ -791,21 +801,7 @@ Remake_Makefiles(void)
 			    gn->name);
 			error_cnt++;
 		} else if (gn->made == UPTODATE) {
-			Lst examine;
-
-			Lst_Init(&examine);
-			Lst_EnQueue(&examine, gn);
-			while (!Lst_IsEmpty(&examine)) {
-				LstNode	*eln;
-				GNode *egn = Lst_DeQueue(&examine);
-
-				egn->make = FALSE;
-				LST_FOREACH(eln, &egn->children) {
-					GNode *cgn = Lst_Datum(eln);
-
-					Lst_EnQueue(&examine, cgn);
-				}
-			}
+			Lst_EnQueue(&cleanup, gn);
 		}
 	}
 
@@ -827,6 +823,24 @@ Remake_Makefiles(void)
 		}
 	}
 
+	while (!Lst_IsEmpty(&cleanup)) {
+		GNode *gn = Lst_DeQueue(&cleanup);
+
+		gn->unmade = 0;
+		gn->make = FALSE;
+		gn->made = UNMADE;
+		gn->childMade = FALSE;
+		gn->mtime = gn->cmtime = 0;
+		gn->cmtime_gn = NULL;
+
+		LST_FOREACH(ln, &gn->children) {
+			GNode *cgn = Lst_Datum(ln);
+
+			gn->unmade++;
+			Lst_EnQueue(&cleanup, cgn);
+		}
+	}
+
 	if (curdir != objdir) {
 		if (chdir(objdir) < 0)
 			Fatal("Failed to change directory to %s.", objdir);
@@ -863,6 +877,7 @@ main(int argc, char **argv)
 	char mdpath[MAXPATHLEN];
 	char obpath[MAXPATHLEN];
 	char cdpath[MAXPATHLEN];
+	char found_dir[MAXPATHLEN + 1];	/* for searching for sys.mk */
 	char *cp = NULL, *start;
 
 	save_argv = argv;
@@ -914,26 +929,6 @@ main(int argc, char **argv)
 	}
 #endif
 
-	/*
-	 * Prior to 7.0, FreeBSD/pc98 kernel used to set the
-	 * utsname.machine to "i386", and MACHINE was defined as
-	 * "i386", so it could not be distinguished from FreeBSD/i386.
-	 * Therefore, we had to check machine.ispc98 and adjust the
-	 * MACHINE variable.  NOTE: The code is still here to be able
-	 * to compile new make binary on old FreeBSD/pc98 systems, and
-	 * have the MACHINE variable set properly.
-	 */
-	if ((machine = getenv("MACHINE")) == NULL) {
-		int	ispc98;
-		size_t	len;
-
-		len = sizeof(ispc98);
-		if (!sysctlbyname("machdep.ispc98", &ispc98, &len, NULL, 0)) {
-			if (ispc98)
-				machine = "pc98";
-		}
-	}
-
 	/*
 	 * Get the name of this type of MACHINE from utsname
 	 * so we can share an executable for similar machines.
@@ -942,7 +937,7 @@ main(int argc, char **argv)
 	 * Note that both MACHINE and MACHINE_ARCH are decided at
 	 * run-time.
 	 */
-	if (machine == NULL) {
+	if ((machine = getenv("MACHINE")) == NULL) {
 		static struct utsname utsname;
 
 		if (uname(&utsname) == -1)
@@ -965,8 +960,6 @@ main(int argc, char **argv)
 	if ((machine_cpu = getenv("MACHINE_CPU")) == NULL) {
 		if (!strcmp(machine_arch, "i386"))
 			machine_cpu = "i386";
-		else if (!strcmp(machine_arch, "alpha"))
-			machine_cpu = "ev4";
 		else
 			machine_cpu = "unknown";
 	}
@@ -1015,6 +1008,12 @@ main(int argc, char **argv)
 	}
 	Job_SetPrefix();
 
+	/*
+	 * Find where we are...
+	 */
+	if (getcwd(curdir, MAXPATHLEN) == NULL)
+		err(2, NULL);
+
 	/*
 	 * First snag things out of the MAKEFLAGS environment
 	 * variable.  Then parse the command line arguments.
@@ -1024,11 +1023,8 @@ main(int argc, char **argv)
 	MainParseArgs(argc, argv);
 
 	/*
-	 * Find where we are...
+	 * Verify that cwd is sane (after -C may have changed it).
 	 */
-	if (getcwd(curdir, MAXPATHLEN) == NULL)
-		err(2, NULL);
-
 	{
 	struct stat sa;
 
@@ -1126,18 +1122,37 @@ main(int argc, char **argv)
 	 * as dir1:...:dirn) to the system include path.
 	 */
 	if (TAILQ_EMPTY(&sysIncPath)) {
-		char syspath[] = PATH_DEFSYSPATH;
+		char defsyspath[] = PATH_DEFSYSPATH;
+		char *syspath = getenv("MAKESYSPATH");
+
+		/*
+		 * If no user-supplied system path was given (thru -m option)
+		 * add the directories from the DEFSYSPATH (more than one may
+		 * be given as dir1:...:dirn) to the system include path.
+		 */
+		if (syspath == NULL || *syspath == '\0')
+			syspath = defsyspath;
+		else
+			syspath = estrdup(syspath);
 
 		for (start = syspath; *start != '\0'; start = cp) {
 			for (cp = start; *cp != '\0' && *cp != ':'; cp++)
 				continue;
-			if (*cp == '\0') {
-				Path_AddDir(&sysIncPath, start);
-			} else {
+			if (*cp == ':') {
 				*cp++ = '\0';
+			}
+			/* look for magic parent directory search string */
+			if (strncmp(".../", start, 4) == 0) {
+				if (Dir_FindHereOrAbove(curdir, start + 4,
+				    found_dir, sizeof(found_dir))) {
+					Path_AddDir(&sysIncPath, found_dir);
+				}
+			} else {
 				Path_AddDir(&sysIncPath, start);
 			}
 		}
+		if (syspath != defsyspath)
+			free(syspath);
 	}
 
 	/*
